@@ -1,13 +1,14 @@
 from normality.cleaning import collapse_spaces, category_replace
 from normality.constants import UNICODE_CATEGORIES, WS
 from normality.transliteration import latinize_text, ascii_text
-from normality.encoding import guess_encoding  # noqa
+from normality.encoding import guess_encoding, guess_file_encoding  # noqa
+from normality.encoding import DEFAULT_ENCODING
 from normality.stringify import stringify  # noqa
 from normality.paths import safe_filename  # noqa
 
 
 def normalize(text, lowercase=True, collapse=True, latinize=False, ascii=False,
-              encoding_default='utf-8', encoding=None,
+              encoding_default=DEFAULT_ENCODING, encoding=None,
               replace_categories=UNICODE_CATEGORIES):
     """The main normalization function for text.
 
