@@ -18,7 +18,7 @@ UNICODE_CATEGORIES = {
     'Zs': WS,
     'Zl': WS,
     'Zp': WS,
-    'Pc': None,
+    'Pc': WS,
     'Pd': WS,
     'Ps': WS,
     'Pe': WS,
@@ -31,9 +31,9 @@ UNICODE_CATEGORIES = {
 }
 
 CONTROL_CODES = {
-    'Cc': None,
-    'Cf': None,
-    'Cs': None,
-    'Co': None,
-    'Cn': None
+    'Cc': WS,
+    'Cf': WS,
+    'Cs': WS,
+    'Co': WS,
+    'Cn': WS
 }
