@@ -2,11 +2,12 @@ import six
 from datetime import datetime, date
 from decimal import Decimal
 
-from normality.cleaning import remove_byte_order_mark
+from normality.cleaning import remove_unsafe_chars
 from normality.encoding import guess_encoding
+from normality.encoding import DEFAULT_ENCODING
 
 
-def stringify(value, encoding_default='utf-8', encoding=None):
+def stringify(value, encoding_default=DEFAULT_ENCODING, encoding=None):
     """Brute-force convert a given object to a string.
 
     This will attempt an increasingly mean set of conversions to make a given
@@ -23,9 +24,9 @@ def stringify(value, encoding_default='utf-8', encoding=None):
             return Decimal(value).to_eng_string()
         elif isinstance(value, six.binary_type):
             if encoding is None:
-                encoding = guess_encoding(value)
-            value = value.decode(encoding, 'ignore')
-            value = remove_byte_order_mark(value)
+                encoding = guess_encoding(value, default=encoding_default)
+            value = value.decode(encoding, 'replace')
+            value = remove_unsafe_chars(value)
         else:
             value = six.text_type(value)
 
